chert
=====

Generates sharp and sparky static sites.

```
$ pip install chert
$ chert init yoursite
$ cd yoursite
$ less TODO.md
```

In action:

* [Sedimental](http://sedimental.org) ([source](https://github.com/mahmoud/sedimental))
* [ENOTUNIQ](http://enotuniq.org)
* [CalVer](http://calver.org)
